@@ -28,6 +28,7 @@
 
 
 #include "zexy.h"
+#include "zexy_strndup.h"
 
 #define MATCHBOX_EXACT 0
 #define MATCHBOX_OSC 1
@@ -212,8 +213,8 @@ static int OSC_PatternMatch (const char *  pattern, const char * test,
     }
   case ']'    :
   case '}'    :
-    z_verbose(1, "[matchbox]: spurious %c in OSC-pattern \".../%s/...\"",
-              pattern[0], theWholePattern);
+    verbose(1, "[matchbox]: spurious %c in OSC-pattern \".../%s/...\"",
+            pattern[0], theWholePattern);
     return FALSE;
   case '['    :
     return OSC_MatchBrackets (pattern,test, theWholePattern);
@@ -246,8 +247,8 @@ static int OSC_MatchBrackets (const char *pattern, const char *test,
   const char *p = pattern;
 
   if (pattern[1] == 0) {
-    z_verbose(1, "[matchbox]: unterminated [ in OSC-pattern \".../%s/...\"",
-              theWholePattern);
+    verbose(1, "[matchbox]: unterminated [ in OSC-pattern \".../%s/...\"",
+            theWholePattern);
     return FALSE;
   }
 
@@ -258,8 +259,8 @@ static int OSC_MatchBrackets (const char *pattern, const char *test,
 
   while (*p != ']') {
     if (*p == 0) {
-      z_verbose(1, "[matchbox]: unterminated [ in OSC-pattern \".../%s/...\"",
-                theWholePattern);
+      verbose(1, "[matchbox]: unterminated [ in OSC-pattern \".../%s/...\"",
+              theWholePattern);
       return FALSE;
     }
     if (p[1] == '-' && p[2] != 0) {
@@ -285,8 +286,8 @@ advance:
 
   while (*p != ']') {
     if (*p == 0) {
-      z_verbose(1, "[matchbox]: unterminated [ in OSC-pattern \".../%s/...\"",
-                theWholePattern);
+      verbose(1, "[matchbox]: unterminated [ in OSC-pattern \".../%s/...\"",
+              theWholePattern);
       return FALSE;
     }
     p++;
@@ -303,8 +304,8 @@ static int OSC_MatchList (const char *pattern, const char *test,
 
   for(restOfPattern = pattern; *restOfPattern != '}'; restOfPattern++) {
     if (*restOfPattern == 0) {
-      z_verbose(1, "[matchbox]: unterminated { in OSC-pattern \".../%s/...\"",
-                theWholePattern);
+      verbose(1, "[matchbox]: unterminated { in OSC-pattern \".../%s/...\"",
+              theWholePattern);
       return FALSE;
     }
   }
@@ -349,7 +350,7 @@ static int atommatch_osc(t_atom*pattern, t_atom*test)
   int result = FALSE;
 
   if(pattern->a_type==A_SYMBOL) {
-    s_pattern=strndup(pattern->a_w.w_symbol->s_name, MAXPDSTRING);
+    s_pattern=zexy_strndup(pattern->a_w.w_symbol->s_name, MAXPDSTRING);
     pattern_size = strnlen(s_pattern, MAXPDSTRING);
   } else {
     pattern_size=sizeof(char)*MAXPDSTRING;
@@ -357,7 +358,7 @@ static int atommatch_osc(t_atom*pattern, t_atom*test)
     atom_string(pattern, s_pattern, pattern_size);
   }
   if(test->a_type==A_SYMBOL) {
-    s_test=strndup(test->a_w.w_symbol->s_name, MAXPDSTRING);
+    s_test=zexy_strndup(test->a_w.w_symbol->s_name, MAXPDSTRING);
     test_size = strnlen(s_test, MAXPDSTRING);
   } else {
     test_size=sizeof(char)*MAXPDSTRING;
@@ -400,7 +401,7 @@ static int atommatch_regex(regex_t*pattern,  t_atom*test)
   }
 
   if(test->a_type==A_SYMBOL) {
-    s_test=strndup(test->a_w.w_symbol->s_name, MAXPDSTRING);
+    s_test=zexy_strndup(test->a_w.w_symbol->s_name, MAXPDSTRING);
     test_size = strnlen(s_test, MAXPDSTRING);
   } else {
     test_size=sizeof(char)*MAXPDSTRING;
@@ -455,7 +456,7 @@ static t_listlist*matchlistlist_regex(unsigned int*numresults,
     int pattern_size=0;
     t_atom*pattern=p_argv+i;
     if(pattern->a_type==A_SYMBOL) {
-      s_pattern=strndup(pattern->a_w.w_symbol->s_name, MAXPDSTRING);
+      s_pattern=zexy_strndup(pattern->a_w.w_symbol->s_name, MAXPDSTRING);
       pattern_size=strnlen(s_pattern, MAXPDSTRING);
     } else {
       pattern_size=sizeof(char)*MAXPDSTRING;
@@ -464,7 +465,7 @@ static t_listlist*matchlistlist_regex(unsigned int*numresults,
     }
     regexpressions[i]=(regex_t*)getbytes(sizeof(regex_t));
     if(regcomp(regexpressions[i], s_pattern, flags)) {
-      z_verbose(1, "[matchbox]: invalid regular expression: %s", s_pattern);
+      verbose(1, "[matchbox]: invalid regular expression: %s", s_pattern);
       if(regexpressions[i]) {
         freebytes(regexpressions[i], sizeof(regex_t));
       }
@@ -597,7 +598,8 @@ static t_listlist*matchlistlist(unsigned int*numresults,
 }
 
 
-static void matchbox_list(t_matchbox*x, t_symbol*s, int argc, t_atom*argv)
+static void matchbox_list(t_matchbox*x, t_symbol*UNUSED(s), int argc,
+                          t_atom*argv)
 {
   unsigned int results=0;
   int mode=x->x_mode;
@@ -613,13 +615,14 @@ static void matchbox_list(t_matchbox*x, t_symbol*s, int argc, t_atom*argv)
   }
 }
 
-static void matchbox_add(t_matchbox*x, t_symbol*s, int argc, t_atom*argv)
+static void matchbox_add(t_matchbox*x, t_symbol*UNUSED(s), int argc,
+                         t_atom*argv)
 {
   /* 1st match, whether we already have this entry */
   if(matchlistlist(0, x->x_lists, argc, argv, MATCHBOX_EXACT, FALSE)) {
     /* already there, skip the rest */
-    z_verbose(1,
-              "[matchbox]: refusing to add already existing list to buffer...");
+    verbose(1,
+            "[matchbox]: refusing to add already existing list to buffer...");
     return;
   }
 
@@ -628,7 +631,7 @@ static void matchbox_add(t_matchbox*x, t_symbol*s, int argc, t_atom*argv)
   x->x_numlists++;
 }
 
-static void matchbox_delete(t_matchbox*x, t_symbol*s, int argc,
+static void matchbox_delete(t_matchbox*x, t_symbol*UNUSED(s), int argc,
                             t_atom*argv)
 {
   unsigned int results=0;
@@ -695,7 +698,7 @@ static void matchbox_mode(t_matchbox*x, t_symbol*s)
   }
 }
 
-static void *matchbox_new(t_symbol *s, int argc, t_atom*argv)
+static void *matchbox_new(t_symbol *UNUSED(s), int argc, t_atom*argv)
 {
   t_matchbox *x = (t_matchbox *)pd_new(matchbox_class);
 
@@ -728,36 +731,30 @@ static void matchbox_free(t_matchbox *x)
   x->x_lists=0;
 }
 
-static void matchbox_help(t_matchbox*x)
+static void matchbox_help(t_matchbox*UNUSED(x))
 {
   post("\n"HEARTSYMBOL " matchbox\t\t:: find a list in a pool of lists");
 }
 
-void matchbox_setup(void)
+ZEXY_SETUP void matchbox_setup(void)
 {
 #ifdef MATCHBOX_OSC
   post("matchbox: OSC-pattern matching code (c) Matt Wright, CNMAT");
 #endif /* MATCHBOX_OSC */
 
 
-  matchbox_class = class_new(gensym("matchbox"), (t_newmethod)matchbox_new,
-                             (t_method)matchbox_free, sizeof(t_matchbox), 0, A_GIMME, 0);
+  matchbox_class = zexy_new("matchbox",
+                            matchbox_new, matchbox_free, t_matchbox, 0, "*");
 
   class_addlist  (matchbox_class, matchbox_list);
 
-  class_addmethod(matchbox_class, (t_method)matchbox_add, gensym("add"),
-                  A_GIMME, 0);
-  class_addmethod(matchbox_class, (t_method)matchbox_delete,
-                  gensym("delete"), A_GIMME, 0);
-  class_addmethod(matchbox_class, (t_method)matchbox_clear, gensym("clear"),
-                  A_NULL, 0);
-  class_addmethod(matchbox_class, (t_method)matchbox_dump, gensym("dump"),
-                  A_NULL);
+  zexy_addmethod(matchbox_class, (t_method)matchbox_add, "add", "*");
+  zexy_addmethod(matchbox_class, (t_method)matchbox_delete, "delete", "*");
+  zexy_addmethod(matchbox_class, (t_method)matchbox_clear, "clear", "");
+  zexy_addmethod(matchbox_class, (t_method)matchbox_dump, "dump", "");
 
-  class_addmethod(matchbox_class, (t_method)matchbox_mode, gensym("mode"),
-                  A_SYMBOL, 0);
+  zexy_addmethod(matchbox_class, (t_method)matchbox_mode, "mode", "s");
 
-  class_addmethod(matchbox_class, (t_method)matchbox_help, gensym("help"),
-                  A_NULL);
+  zexy_addmethod(matchbox_class, (t_method)matchbox_help, "help", "");
   zexy_register("matchbox");
 }
